package de.frajul.endlessroll.views;

import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;

import java.util.ArrayList;
import java.util.List;

import de.frajul.endlessroll.R;
import de.frajul.endlessroll.levels.Level;
import de.frajul.endlessroll.levels.LevelPack;
import de.frajul.endlessroll.main.GameActivity;
import de.frajul.endlessroll.main.GameHandler;
import de.frajul.endlessroll.main.game.Game;
import de.frajul.endlessroll.main.game.Timer;
import de.frajul.endlessroll.main.screens.GameScreen;
import de.frajul.endlessroll.user.User;

/**
 * Created by Julian on 11.12.2015.
 */
public class ViewManager implements View.OnClickListener {

    private GameHandler gameViewHandler;
    private Game game;
    private GameActivity gameActivity;

    private TextView fpsView;
    private TextView playerProgress;
    private ImageView pauseButton;
    private GameOverMessage gameOverMessage;
    private GoalMessage goalMessage;
    public ShortMenu shortMenu;

    private boolean showFps = false;

    private List<BombErrorMessage> bombErrorMessages = new ArrayList<>();

    private String fpsFormat, playerProgressFormat;

    public ViewManager(final Game game, final GameScreen gameScreen, final GameHandler gameViewHandler, final GameActivity gameActivity) {
        this.game = game;
        this.gameViewHandler = gameViewHandler;
        this.gameActivity = gameActivity;

        final RelativeLayout layout = gameViewHandler.getRootLayout();
        gameViewHandler.startInUiThread(new Runnable() {
            @Override
            public void run() {
                shortMenu = new ShortMenu(game, gameScreen, gameActivity,
                        layout.findViewById(R.id.game_shortmenu));
                gameOverMessage = new GameOverMessage(game, gameScreen, gameActivity,
                        layout.findViewById(R.id.game_game_over_message));
                goalMessage = new GoalMessage(game, gameScreen, gameActivity,
                        layout.findViewById(R.id.game_goal_message));
            }
        });
        pauseButton = (ImageView) layout.findViewById(R.id.game_pausebutton);
        pauseButton.setOnClickListener(this);
        playerProgress = (TextView) layout.findViewById(R.id.game_playerprogress);
        playerProgress.setTypeface(gameActivity.getTypeface());
        fpsView = (TextView) layout.findViewById(R.id.game_fps);
        fpsView.setTypeface(gameActivity.getTypeface());

        fpsFormat = game.getContext().getString(R.string.game_fps_format_d);
        playerProgressFormat = game.getContext().getString(R.string.game_playerprogress_format_f);
    }

    public void prepareToBeShown() {
        if (shortMenu.isVisible())
            shortMenu.prepareToBeShown();
        if (gameOverMessage.isVisible())
            gameOverMessage.prepareToBeShown();
        if (goalMessage.isVisible())
            goalMessage.prepareToBeShown();
    }

    public void showBombErrorMessage(float xPos, float yPos) {
        for (BombErrorMessage bombErrorMessage : bombErrorMessages) {
            if (!bombErrorMessage.isAnimationRunning()) {
                bombErrorMessage.show(xPos, yPos);
                return;
            }
        }
        BombErrorMessage bombErrorMessage = new BombErrorMessage(gameActivity);
        bombErrorMessage.show(xPos, yPos);
        gameViewHandler.getRootLayout().addView(bombErrorMessage.getView());
        bombErrorMessages.add(bombErrorMessage);
    }

    @Override
    public void onClick(View v) {
        game.tryToPause();
    }

    public void resetViews() {
        gameViewHandler.startInUiThread(new Runnable() {
            @Override
            public void run() {
                playerProgress.setText(R.string.game_playerprogress_placeholder);
            }
        });
    }

    public void onGoalMessageKeyBack() {
        goalMessage.onKeyBack();
    }

    public void showGameOverMessage() {
        gameViewHandler.startInUiThread(new Runnable() {
            @Override
            public void run() {
                gameOverMessage.fadeIn();
            }
        });
    }

    public void showGoalMessage(final LevelPack levelPack, final Level level) {
        gameViewHandler.startInUiThread(new Runnable() {
            @Override
            public void run() {
                goalMessage.fadeInWithDelay(levelPack, level);
            }
        });
    }

    public void showShortMenu() {
        shortMenu.startAnims();
        shortMenu.setVisible(true);
    }

    public void hideShortMenu() {
        shortMenu.setVisible(false);
    }

    public void update(final boolean gameRunning, final Timer timer, final float playerX) {
        gameViewHandler.startInUiThread(new Runnable() {
            @Override
            public void run() {
                if (showFps)
                    fpsView.setText(String.format(fpsFormat, timer.getFps()));
                if (gameRunning) {
                    playerProgress.setText(String.format(playerProgressFormat, toMeters(playerX)));
                }
            }
        });
    }

    private float toMeters(float value) {
        return ((int) (value * 20)) / 10f;
    }

    public boolean isShortMenuVisible() {
        return shortMenu.isVisible();
    }

    public void setShowFps(final boolean showFps) {
        fpsView.setVisibility(showFps ? View.VISIBLE : View.GONE);
        this.showFps = showFps;
    }

}
